# Summary
| Parameter                                    | Value
|----------------------------------------------|---------------
| Candles count:                               | 150
| Timeframe:                                   | 4:00:00
| Precision (signs after comma):               | 2
| Close first:                                 | 15311.8
| Close last:                                  | 15530.3
| Close max:                                   | 17727.91
| Close min:                                   | 14404.07
| Diapason (between max and min close prices): | 3323.84
| Trend (between close first and close last:   | NO trend

# Some statistics
| Statistic                                    | Value
|----------------------------------------------|---------------
| Up candles count:                            | 77 (51.33%)
| Down candles count:                          | 73 (48.67%)
| Max of up / down candle chains:              | 5 / 4
| Max delta (between High and Low prices):     | 1522.06
| Min delta (between High and Low prices):     | 3.76
| Delta's std. dev.:                           | 274.2
| - 99 percentile:                             | ≤ 1260.38
| - 95 percentile:                             | ≤ 834.1
| - 80 percentile:                             | ≤ 667.77
| Cumulative sum of volumes:                   | 31475461